@@ -1054,9 +1054,9 @@ Boolean selectarea(objectptr selobj, XPoint *boxpts, short level)
 	      tlinfo.dostop = j + 1;
 	      tmpext = ULength(slab, areawin->topinstance, &tlinfo);
 	      tmpl2 = tmpext.maxwidth;
-	      if (slab->anchor & JUSTIFYRIGHT)
+	      if ((slab->anchor & JUSTIFYRIGHT) && tlinfo.padding)
 	         padding = (int)tlinfo.padding[tlinfo.line];
-	      else if (slab->anchor & TEXTCENTERED)
+	      else if ((slab->anchor & TEXTCENTERED) && tlinfo.padding)
 	         padding = (int)(0.5 * tlinfo.padding[tlinfo.line]);
 	      else
 		 padding = 0;
